==> PHPTAL-1.2.1b1.tar.gz: PHPTAL-1.2.1b1/tests/PhptalPathTest.php <==
<?php
/**
 * PHPTAL templating engine
 *
 * PHP Version 5
 *
 * @category HTML
 * @package  PHPTAL
 * @author   Laurent Bedubourg <lbedubourg@motion-twin.com>
 * @author   Kornel Lesiński <kornel@aardvarkmedia.co.uk>
 * @license  http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @version  SVN: $Id: PhptalPathTest.php 657 2009-06-30 16:48:20Z kornel $
 * @link     http://phptal.org/
 */

require_once dirname(__FILE__)."/config.php";

PHPTAL::setIncludePath();
require_once 'PHPTAL/Context.php';
PHPTAL::restoreIncludePath();
 
class PhptalPathTest_DummyClass
{
    public $foo;
}

/* protected get/isset doesn't work in PHP 5.3
class PhptalPathTest_DummyIssetClass
{
    protected function __isset($isset)
    {
        return false;
    }
}

class PhptalPathTest_DummyGetClass
{
    protected function __get($anything)
    {
        return 'whatever';
    }
}
*/

class PhptalPathTest extends PHPTAL_TestCase
{
    function testZeroIndex()
    {
        $data   = array(1, 0, 3);
        $result = PHPTAL_Context::path($data, '0');
        $this->assertEquals(1, $result);
    }

    /* protected get/isset doesn't work in PHP 5.3
    function testProtectedIsset()
    {
        $tpl = $this->newPHPTAL();
        $tpl->protected = new PhptalPathTest_DummyIssetClass;
        $tpl->setSource('<p tal:content="protected/fail | \'ok\'"></p>');
        $res = $tpl->execute();
        $this->assertEquals($res,'<p>ok</p>');
    }

    function testProtectedGet()
    {
        $tpl = $this->newPHPTAL();
        $tpl->protected = new PhptalPathTest_DummyGetClass;
        $tpl->setSource('<p tal:content="protected/fail | \'ok\'"></p>');
        $res = $tpl->execute();
        $this->assertEquals($res,'<p>ok</p>');
    }
    */

    function testDefinedButNullProperty()
    {
        $src = <<<EOS
<span tal:content="o/foo"/>
<span tal:content="o/foo | string:blah"/>
<span tal:content="o/bar" tal:on-error="string:ok"/>
EOS;
        $exp = <<<EOS
<span></span>
<span>blah</span>
ok
EOS;

        $tpl = $this->newPHPTAL();
        $tpl->setSource($src, __FILE__);
        $tpl->o = new PhptalPathTest_DummyClass();
        $res = $tpl->execute();

        $this->assertEquals($exp, $res);
    }
}

==> PHPTAL-1.2.2b1.tar.gz: PHPTAL-1.2.2b1/tests/PhptalPathTest.php <==
<?php
/**
 * PHPTAL templating engine
 *
 * PHP Version 5
 *
 * @category HTML
 * @package  PHPTAL
 * @author   Laurent Bedubourg <lbedubourg@motion-twin.com>
 * @author   Kornel Lesiński <kornel@aardvarkmedia.co.uk>
 * @license  http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 * @version  SVN: $Id: $
 * @link     http://phptal.org/
 */

require_once dirname(__FILE__)."/config.php";


class PhptalPathTest_DummyClass
{
    public $foo;

    protected function protTest()
    {
        return 'prot-method';
    }

    public $protTest = 'prot-property';

    public function pubTest()
    {
        return 'pub-method';
    }

    public $pubTest = 'pub-property';
}

class PhptalPathTest extends PHPTAL_TestCase
{
    function testZeroIndex()
    {
        $data   = array(1, 0, 3);
        $result = PHPTAL_Context::path($data, '0');
        $this->assertEquals(1, $result);
    }

    function testProtectedMethodIgnored()
    {
        $tpl = $this->newPHPTAL();
        $tpl->obj = new PhptalPathTest_DummyClass();
        $tpl->setSource('<test tal:content="obj/protTest"></test>');

        $this->assertEquals('<test>prot-property</test>', $tpl->execute());
    }

    function testPublicMethodFirst()
    {
        $tpl = $this->newPHPTAL();
        $tpl->obj = new PhptalPathTest_DummyClass();
        $tpl->setSource('<test tal:content="obj/pubTest"></test>');

        $this->assertEquals('<test>pub-method</test>', $tpl->execute());
    }

    function testDefinedButNullProperty()
    {
        $src = <<<EOS
<span tal:content="o/foo"/>
<span tal:content="o/foo | string:blah"/>
<span tal:content="o/bar" tal:on-error="string:ok"/>
EOS;
        $exp = <<<EOS
<span></span>
<span>blah</span>
ok
EOS;

        $tpl = $this->newPHPTAL();
        $tpl->setSource($src, __FILE__);
        $tpl->o = new PhptalPathTest_DummyClass();
        $res = $tpl->execute();

        $this->assertEquals($exp, $res);
    }
}
